@@ -13,7 +13,7 @@ class CommonDataElement:
     def from_metadata(cls, metadata):
         code = metadata["code"]
         if not code.isidentifier():
-            raise UserInputError(f'CDE: {code} is not a valid python identifier')
+            raise UserInputError(f"CDE: {code} is not a valid python identifier")
 
         validate_metadata(code, metadata)
         metadata = json.dumps(metadata)
@@ -24,16 +24,6 @@ class CommonDataElement:
         )
 
 
-def get_system_column_metadata():
-    subjectcode = {
-        "is_categorical": False,
-        "label": "subjectcode",
-        "code": "subjectcode",
-        "sql_type": "text",
-    }
-    return CommonDataElement.from_metadata(subjectcode)
-
-
 def make_cdes(schema_data):
     cdes = []
 
@@ -50,6 +40,17 @@ def make_cdes(schema_data):
     return cdes
 
 
+def validate_dataset_present_on_cdes_with_proper_format(cdes):
+    dataset_cde = [cde for cde in cdes if cde.code == "dataset"]
+    if not dataset_cde:
+        raise InvalidDataModelError("There is no dataset cde in the data model's CDEs")
+    dataset_metadata = json.loads(dataset_cde[0].metadata)
+    if not dataset_metadata["is_categorical"]:
+        raise InvalidDataModelError("Dataset cde should be categorical")
+    if dataset_metadata["sql_type"] != "text":
+        raise InvalidDataModelError("Dataset cde should have sql type 'text'")
+
+
 def reformat_metadata(metadata):
     new_key_assign = {
         "isCategorical": "is_categorical",
